@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-import os
 import time
 from random import randint
 from flask import session, flash, request, url_for, render_template as tpl
@@ -8,35 +7,27 @@ from flask_babelex import gettext, lazy_gettext
 from exonutils.buffers.filebuffer import SimpleFileBuffer
 from exonwebui.menuboard import MenuBoardView
 
+# board menu buffer
+MENU_BUFFER = {}
+
 
 class Index(MenuBoardView):
     routes = [('/', 'index')]
 
     def initialize(self):
-        # disable strict slash matching
-        self.parent.app.url_map.strict_slashes = False
-
-        # adjust session and csrf cookies attrs
-        self.parent.app.config['SESSION_COOKIE_HTTPONLY'] = True
-        self.parent.app.config['SESSION_COOKIE_SAMESITE'] = 'Lax'
-        self.parent.app.config['CSRF_COOKIE_HTTPONLY'] = True
-        self.parent.app.config['CSRF_COOKIE_SAMESITE'] = 'Lax'
-        self.parent.app.config['CSRF_DISABLE'] = True
-
-        # initialize board
-        locale_path = os.path.join(self.parent.base_path, 'locale')
-        self.board_initialize(self.parent.app, locale_path=locale_path)
-
-        # add menu section
+        global MENU_BUFFER
         self.add_menulink(
-            self.parent.app, 1,
+            MENU_BUFFER, 1,
             lazy_gettext('UI Components'), icon='fa-cubes')
 
-    def get(self, *args, **kwargs):
+    def get(self, **kwargs):
+        global MENU_BUFFER
+
         params = {
             'doc_lang': session.get('lang', ''),
             'doc_langdir': session.get('lang_dir', ''),
             'doc_title': "WebUI",
+            'menu': MENU_BUFFER,
         }
 
         if not session.get('simpleboard', None):
@@ -46,21 +37,22 @@ class Index(MenuBoardView):
             return self.redirect(url_for('index'))
 
         if session.get('simpleboard', False):
-            return self.reply(tpl('simpleboard.tpl', **params))
+            return tpl('simpleboard.min.tpl', **params)
         else:
-            return self.reply(tpl('mainboard.tpl', **params))
+            return tpl('mainboard.min.tpl', **params)
 
 
 class Home(MenuBoardView):
     routes = [('/home', 'home')]
 
     def initialize(self):
+        global MENU_BUFFER
         self.add_menulink(
-            self.parent.app, 0,
+            MENU_BUFFER, 0,
             lazy_gettext('Home'), icon='fa-home', url='#home')
 
-    def get(self, *args, **kwargs):
-        html = tpl('option_panel.tpl', message=gettext("Welcome"))
+    def get(self, **kwargs):
+        html = tpl('option_panel.min.tpl', message=gettext("Welcome"))
         return self.reply(html, doctitle=gettext('Home'))
 
 
@@ -68,11 +60,12 @@ class Notify(MenuBoardView):
     routes = [('/notify', 'notify')]
 
     def initialize(self):
+        global MENU_BUFFER
         self.add_menulink(
-            self.parent.app, 1,
+            MENU_BUFFER, 1,
             lazy_gettext('Notifications'), url='#notify', parent=1)
 
-    def get(self, *args, **kwargs):
+    def get(self, **kwargs):
         from exonwebui.macros.basic import UiAlert
         flash(gettext('error') + " STICKY_MSG", 'error.us')
         flash(gettext('warning'), 'warn')
@@ -87,11 +80,12 @@ class Alerts(MenuBoardView):
     routes = [('/alerts', 'alerts')]
 
     def initialize(self):
+        global MENU_BUFFER
         self.add_menulink(
-            self.parent.app, 2,
+            MENU_BUFFER, 2,
             lazy_gettext('Alerts'), url='#alerts', parent=1)
 
-    def get(self, *args, **kwargs):
+    def get(self, **kwargs):
         from exonwebui.macros.basic import UiAlert
         html = UiAlert('info', gettext('info'), styles='px-3 pt-3')
         html += UiAlert('warn', gettext('warning'), styles='px-3')
@@ -105,11 +99,12 @@ class InputForm(MenuBoardView):
     routes = [('/inputform', 'inputform')]
 
     def initialize(self):
+        global MENU_BUFFER
         self.add_menulink(
-            self.parent.app, 3,
+            MENU_BUFFER, 3,
             lazy_gettext('Input Form'), url='#inputform', parent=1)
 
-    def get(self, *args, **kwargs):
+    def get(self, **kwargs):
         from exonwebui.macros.forms import UiInputForm
         options = {
             'form_id': "1234",
@@ -207,10 +202,10 @@ class InputForm(MenuBoardView):
                  'helpguide': gettext("Extra detailed long help for fields")},
             ]
         }
-        html = tpl('input_form.tpl', contents=UiInputForm(options))
+        html = tpl('input_form.min.tpl', contents=UiInputForm(options))
         return self.reply(html, doctitle=gettext('Input Form'))
 
-    def post(self, *args, **kwargs):
+    def post(self, **kwargs):
         validation = request.form.get('validation', '')
         if validation == '1':
             params = {
@@ -240,11 +235,12 @@ class Datagrid(MenuBoardView):
               ('/datagrid/<action>', 'datagrid_1')]
 
     def initialize(self):
+        global MENU_BUFFER
         self.add_menulink(
-            self.parent.app, 4,
+            MENU_BUFFER, 4,
             lazy_gettext('Datagrid'), url='#datagrid', parent=1)
 
-    def get(self, *args, **kwargs):
+    def get(self, **kwargs):
         from exonwebui.macros.datagrids import UiStdDataGrid
         options = {
             'grid_id': "1234",
@@ -287,11 +283,14 @@ class Datagrid(MenuBoardView):
                 {'label': 'Op 3 with Reload', 'action': "group_op3"},
             ],
         }
-        html = tpl('data_grid.tpl', contents=UiStdDataGrid(options))
+        html = tpl('data_grid.min.tpl', contents=UiStdDataGrid(options))
         return self.reply(html, doctitle=gettext('Datagrid'))
 
-    def post(self, action='', **kwargs):
+    def post(self, **kwargs):
         from exonwebui.macros.datagrids import UiStdDataGrid
+
+        action = kwargs.get('action') or ''
+
         if action == 'loaddata':
             data = []
             for k in range(228):
@@ -347,11 +346,12 @@ class QueryBuilder(MenuBoardView):
     routes = [('/qbuilder', 'qbuilder')]
 
     def initialize(self):
+        global MENU_BUFFER
         self.add_menulink(
-            self.parent.app, 5,
+            MENU_BUFFER, 5,
             lazy_gettext('Query Builder'), url='#qbuilder', parent=1)
 
-    def get(self, *args, **kwargs):
+    def get(self, **kwargs):
         from exonwebui.macros.forms import UiQBuilder
         options = {
             'form_id': "1234",
@@ -407,7 +407,7 @@ class QueryBuilder(MenuBoardView):
                 ],
             },
         }
-        html = tpl('query_builder.tpl', contents=UiQBuilder(options))
+        html = tpl('query_builder.min.tpl', contents=UiQBuilder(options))
         return self.reply(html, doctitle=gettext('Query Builder'))
 
 
@@ -416,22 +416,23 @@ class Loader(MenuBoardView):
     shared_buffer = SimpleFileBuffer('SampleWebui_Loader')
 
     def initialize(self):
+        global MENU_BUFFER
         self.add_menulink(
-            self.parent.app, 2,
+            MENU_BUFFER, 2,
             lazy_gettext('Page Loader'), url='#loader')
 
-    def get(self, *args, **kwargs):
+    def get(self, **kwargs):
         from exonwebui.macros.basic import UiAlert
         html = UiAlert('message', gettext('loaded after delay'),
                        styles='p-3', dismiss=False)
-        html += tpl('progress_loader.tpl')
+        html += tpl('progress_loader.min.tpl')
 
         # simulate delay
         time.sleep(3)
 
         return self.reply(html, doctitle=gettext('Page Loader'))
 
-    def post(self, *args, **kwargs):
+    def post(self, **kwargs):
         # get loading progress status
         if request.form.get('get_progress', ''):
             res = self.shared_buffer.get('loader_progress', 0)
@@ -442,7 +443,7 @@ class Loader(MenuBoardView):
         for i in range(t):
             try:
                 self.shared_buffer.set('loader_progress', int(i * 100 / t))
-            except:
+            except Exception:
                 pass
             time.sleep(1)
 
@@ -455,13 +456,16 @@ class Loginpage(MenuBoardView):
               ('/loginpage/<action>', 'loginpage_1')]
 
     def initialize(self):
+        global MENU_BUFFER
         self.add_menulink(
-            self.parent.app, 3,
+            MENU_BUFFER, 3,
             lazy_gettext('Login Page'), url='loginpage')
 
-    def get(self, action='', **kwargs):
+    def get(self, **kwargs):
         from exonwebui.macros.forms import UiLoginForm
 
+        action = kwargs.get('action') or ''
+
         if action == 'load':
             html = UiLoginForm(
                 {'submit_url': url_for('loginpage'), 'authkey': '123456'},
@@ -474,9 +478,9 @@ class Loginpage(MenuBoardView):
                 'doc_title': "WebUI",
                 'load_url': "%s/load" % url_for('loginpage'),
             }
-            return self.reply(tpl('loginpage.tpl', **params))
+            return tpl('loginpage.min.tpl', **params)
 
-    def post(self):
+    def post(self, **kwargs):
         username = request.form.get('username', '')
         authdigest = request.form.get('digest', '')
 
